pub struct Node { /* private fields */ }Expand description
An individual card within a tier.
Nodes are the primary visual elements of a dendryform diagram. Each node has a colored top-bar, an icon, title, description, and optional technology badges.
Construct via NodeBuilder or deserialize from YAML/JSON.
Implementations
Sourceimpl Node
impl Node
Sourcepub fn builder() -> NodeBuilder
pub fn builder() -> NodeBuilder
Creates a new NodeBuilder.
Sourcepub fn description(&self) -> &str
pub fn description(&self) -> &str
Returns the description.