pub struct ThemePalette(/* private fields */);Implementations
Sourceimpl ThemePalette
impl ThemePalette
Sourcepub fn get(&self, color: Color) -> Option<&ColorSet>
pub fn get(&self, color: Color) -> Option<&ColorSet>
Returns the color set for a given color, if defined.
Sourcepub fn iter(&self) -> impl Iterator<Item = (&Color, &ColorSet)>
pub fn iter(&self) -> impl Iterator<Item = (&Color, &ColorSet)>
Returns an iterator over all palette entries.
Sourcepub fn merge(&mut self, overrides: ThemePalette)
pub fn merge(&mut self, overrides: ThemePalette)
Merges another palette on top of this one (overrides win).